\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{qipc2011}[2011/02/21 v1.0 QIPC 2011 abstract template]

\LoadClass[11pt,a4paper]{article}
\RequirePackage[a4paper,portrait]{geometry}
\geometry{lmargin=72.0bp,rmargin=72.0bp,tmargin=72.0bp,bmargin=72.0bp}

\pagestyle{empty}

\renewcommand{\refname}{\vspace{-6ex}}

\newcommand*{\@correspondingauthorgivenname}{}
\newcommand*{\CorrespondingAuthorGivenName}[1]{\renewcommand*{\@correspondingauthorgivenname}{#1}}

\newcommand*{\@correspondingauthorsurname}{}
\newcommand*{\CorrespondingAuthorSurname}[1]{\renewcommand*{\@correspondingauthorsurname}{#1}}

\newcommand*{\@correspondingauthoremail}{}
\newcommand*{\CorrespondingAuthorEmail}[1]{\renewcommand*{\@correspondingauthoremail}{#1}}

\def\box@checked{\fbox{\tt X}}
\def\box@open{\fbox{$\phantom{\hbox{\tt X}}$}}

\def\presentationtype#1{\gdef\@presentationtype{#1}}
\def\@presentationtype{}

\newcommand*{\reset@presentationtype}{
    \def\presentationtype@invited{\box@open}
    \def\presentationtype@oral{\box@open}
    \def\presentationtype@poster{\box@open}% \quad Prefer Contributed Oral\\
}

\reset@presentationtype

\let\PresentationType=\presentationtype

\newcommand*{\@abstracttitle}{\rule{0pt}{1cm}}
\newcommand*{\Title}[1]{\renewcommand*{\@abstracttitle}{#1}}

\newcommand*{\@authorslist}{\rule{0pt}{1cm}}
\newcommand*{\AuthorsList}[1]{\renewcommand*{\@authorslist}{#1}}

\newcommand{\@affiliations}{\rule{0pt}{1cm}}
\newcommand{\Affiliations}[1]{\renewcommand{\@affiliations}{#1}}

\newlength\boxwidth
\newlength\boxheight

\newcommand{\@abstract}{}
\newcommand{\Abstract}[1]{\renewcommand{\@abstract}{#1}}

%\def\topic#1{\gdef\@topic{#1}}
\newcommand*{\@validtopics}{
    {atomicsystems}{Atomic systems},
    {chargesandspins}{Charges and spins},
    {mechanical}{Mechanical oscillators},
    {photons}{Photons},
    {communication}{Quantum communication},
    {infotheory}{Quantum information theory},
    {special}{Special topics: topological effects, quantum simulations, precision measurements},
    {superconducting}{Superconducting circuits},
    {other}{Other topic}
}

\newcommand*{\@validtopicoutput}{
    {atomicsystems}{Topic: Atomic systems},
    {chargesandspins}{Topic: Charges and spins},
    {mechanical}{Topic: Mechanical oscillators},
    {photons}{Topic: Photons},
    {communication}{Topic: Quantum communication},
    {infotheory}{Topic: Quantum information theory},
    {special}{Topic: Special topics: topological effects, quantum simulations, precision measurements},
    {superconducting}{Topic: Superconducting circuits},
    {other}{Topic: Other topic}
}

\newcommand*{\get@topic}[2]{
    \def\@topic@label{#1}
    \def\@topic@text{#2}
}

\newcommand*{\reset@topics}{
    \@for\@topic:=\@validtopics\do{
        \expandafter\get@topic\@topic
        \@namedef{topic@\@topic@label}{\empty}
    }
}

\reset@topics

\newcommand*{\Topic}[1]{
    \@ifundefined{topic@#1}
    {
        \def\@topicoptions{}
        \def\@topicoptionssep{}
        \@for\@topic:=\@validtopics\do{
            \expandafter\get@topic\@topic
            \edef\@topicoptions{\@topicoptions\@topicoptionssep\@topic@label --> \@topic@text}
            \def\@topicoptionssep{, }
        }
        \ClassError{qipc2011}{Unknown topic `#1'}
        {Available options: \@topicoptions}
    }
    {
        \reset@topics
%        \@for\@topic:=\@validtopics\do{
            \@namedef{topic@#1}{\@topic@text}
%        }
    }
}

%\let\Topic=\topics

\newenvironment{thebibliographyQIPC}
{\small
\begin{thebibliography}}
{\end{thebibliography}}

\newcommand{\createabstract}{%

    \newif \iforal@presentationtype \oral@presentationtypefalse
    \newif \ifposter@presentationtype \poster@presentationtypefalse
    \newif \ifinvited@presentationtype \invited@presentationtypefalse

    \setlength{\boxheight}{8.8cm}
    \def\@tempa{invited}
    \ifx \@tempa\@presentationtype \invited@presentationtypetrue \setlength{\boxheight}{19.3cm} \else
        \def\@tempa{oral}
        \ifx\@presentationtype\@tempa \oral@presentationtypetrue \else
            \def\@tempa{poster}
            \ifx\@presentationtype\@tempa \poster@presentationtypetrue \else
                \ClassError{qipc2011}{Unknown presentation type \@presentationtype}
                {Presentation can be either `invited' or `oral' or `poster'}
            \fi
        \fi
    \fi

    {\begin{center}
        \large \bf
        Abstract Submitted to the International Conference on\\
        Quantum Information Processing and Communication (QIPC) 2011
    \end{center}}
    \vspace{0.25cm}

    \bgroup\centering
    \setlength{\boxwidth}{13cm}
    \addtolength{\boxwidth}{-2\fboxsep}
    \addtolength{\boxwidth}{-2\fboxrule}
    \addtolength{\boxheight}{-2\fboxsep}%
    \addtolength{\boxheight}{-2\fboxrule}%
    \fbox{
    \vbox to \boxheight {
%        \vfil
        \vspace{-.4cm}
        \hbox to \boxwidth{
            \parbox{\boxwidth}{
                \begin{flushleft}
                    {\bf\@abstracttitle}\\
                    \vspace{0.5ex}
                    \@authorslist\\
                    \vspace{0.5ex}
                    {\small\@affiliations}
                \end{flushleft}
                \vspace{-2ex}
                \@abstract
                \endabstract
            }
        }
        \vfil
    }
    }

    \vspace{0.25cm}

    {
        \begin{tabular}[b]{l}
            \ifinvited@presentationtype\box@checked\else\box@open\fi\quad Invited Talk\\
            \iforal@presentationtype\box@checked\else\box@open\fi\quad  Prefer Contributed Oral Presentation\\
            \ifposter@presentationtype\box@checked\else\box@open\fi\quad Prefer Poster Presentation\\
        \end{tabular}
        \hfil
        \begin{tabular}[b]{r}
            \@correspondingauthorgivenname\space\@correspondingauthorsurname\\
            \@correspondingauthoremail\\
            \par\\
        \end{tabular}
    }

    \vspace{0.25cm}
    \egroup
%    \begin{flushleft}
    \@for\@topic:=\@validtopicoutput\do{
        \expandafter\get@topic\@topic
        \@nameuse{topic@\@topic@label}
    }
%    \end{flushleft}
}
\endinput